@@ -1,26 +1,14 @@
 /*
- * This file is part of KDevelop
- * Copyright 2010 Aleix Pol Gonzalez <aleixpol@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2010 Aleix Pol Gonzalez <aleixpol@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KDEVPLATFORM_PLUGIN_REVIEWBOARDJOBS_H
 #define KDEVPLATFORM_PLUGIN_REVIEWBOARDJOBS_H
 
+#include "reviewboardhelpers_export.h"
+
 #include <QList>
 #include <QNetworkAccessManager>
 #include <QPair>
@@ -38,7 +26,7 @@ namespace ReviewBoard
      *
      * @note It is reviewboard-agnostic.
      */
-    class Q_DECL_EXPORT HttpCall : public KJob
+    class REVIEWBOARDHELPERS_EXPORT HttpCall : public KJob
     {
         Q_OBJECT
         Q_PROPERTY(QVariant result READ result)
@@ -47,7 +35,7 @@ namespace ReviewBoard
 
             HttpCall(const QUrl& s, const QString& apiPath, const QList<QPair<QString,QString> >& queryParameters, Method m, const QByteArray& post, bool multipart, QObject* parent);
 
-            virtual void start() override;
+            void start() override;
 
             QVariant result() const;
 
@@ -66,7 +54,7 @@ namespace ReviewBoard
             Method m_method;
     };
 
-    class Q_DECL_EXPORT ReviewRequest : public KJob
+    class REVIEWBOARDHELPERS_EXPORT ReviewRequest : public KJob
     {
         Q_OBJECT
         public:
@@ -81,12 +69,12 @@ namespace ReviewBoard
             QString m_id;
     };
 
-    class Q_DECL_EXPORT NewRequest : public ReviewRequest
+    class REVIEWBOARDHELPERS_EXPORT NewRequest : public ReviewRequest
     {
         Q_OBJECT
         public:
-            NewRequest(const QUrl& server, const QString& project, QObject* parent = 0);
-            virtual void start() override;
+            NewRequest(const QUrl& server, const QString& project, QObject* parent = nullptr);
+            void start() override;
 
         private Q_SLOTS:
             void done();
@@ -96,12 +84,12 @@ namespace ReviewBoard
             QString m_project;
     };
 
-    class Q_DECL_EXPORT UpdateRequest : public ReviewRequest
+    class REVIEWBOARDHELPERS_EXPORT UpdateRequest : public ReviewRequest
     {
         Q_OBJECT
         public:
             UpdateRequest(const QUrl& server, const QString& id, const QVariantMap& newValues, QObject* parent = nullptr);
-            virtual void start() override;
+            void start() override;
 
         private Q_SLOTS:
             void done();
@@ -111,12 +99,12 @@ namespace ReviewBoard
             QString m_project;
     };
 
-    class Q_DECL_EXPORT SubmitPatchRequest : public ReviewRequest
+    class REVIEWBOARDHELPERS_EXPORT SubmitPatchRequest : public ReviewRequest
     {
         Q_OBJECT
         public:
-            SubmitPatchRequest(const QUrl &server, const QUrl& patch, const QString& basedir, const QString& id, QObject* parent = 0);
-            virtual void start() override;
+            SubmitPatchRequest(const QUrl &server, const QUrl& patch, const QString& basedir, const QString& id, QObject* parent = nullptr);
+            void start() override;
 
         private Q_SLOTS:
             void done();
@@ -127,12 +115,12 @@ namespace ReviewBoard
             QString m_basedir;
     };
 
-    class Q_DECL_EXPORT ProjectsListRequest : public KJob
+    class REVIEWBOARDHELPERS_EXPORT ProjectsListRequest : public KJob
     {
         Q_OBJECT
         public:
-            ProjectsListRequest(const QUrl &server, QObject* parent = 0);
-            virtual void start() override;
+            ProjectsListRequest(const QUrl &server, QObject* parent = nullptr);
+            void start() override;
             QVariantList repositories() const;
 
         private Q_SLOTS:
@@ -144,12 +132,12 @@ namespace ReviewBoard
             QVariantList m_repositories;
     };
 
-    class Q_DECL_EXPORT ReviewListRequest : public KJob
+    class REVIEWBOARDHELPERS_EXPORT ReviewListRequest : public KJob
     {
         Q_OBJECT
         public:
-            ReviewListRequest(const QUrl& server, const QString& user, const QString& reviewStatus, QObject* parent = 0);
-            virtual void start() override;
+            ReviewListRequest(const QUrl& server, const QString& user, const QString& reviewStatus, QObject* parent = nullptr);
+            void start() override;
             QVariantList reviews() const;
 
         private Q_SLOTS:
